@@ -1,9 +1,8 @@
 """Generate raw float dataframe."""
 
-from psycopmlutils.synth_data_generator.synth_col_generators import (
+from psycop_ml_utils.synth_data_generator.synth_col_generators import (
     generate_data_columns,
 )
-
 from timeseriesflattener.utils import PROJECT_ROOT
 
 if __name__ == "__main__":
